@@ -6,32 +6,33 @@ import tempfile
 import gdb
 
 import pwndbg.commands
-import pwndbg.vmmap
+import pwndbg.gdblib.vmmap
+from pwndbg.commands import CommandCategory
 
-parser = argparse.ArgumentParser(description="Dump ROP gadgets with Jon Salwan's ROPgadget tool.",
-                                epilog="Example: rop --grep 'pop rdi' -- --nojop")
-parser.add_argument('--grep', type=str,
-                    help='String to grep the output for')
-parser.add_argument('argument', nargs='*', type=str,
-                    help='Arguments to pass to ROPgadget')
+parser = argparse.ArgumentParser(
+    description="Dump ROP gadgets with Jon Salwan's ROPgadget tool.",
+    epilog="Example: rop --grep 'pop rdi' -- --nojop",
+)
+parser.add_argument("--grep", type=str, help="String to grep the output for")
+parser.add_argument("argument", nargs="*", type=str, help="Arguments to pass to ROPgadget")
 
 
-@pwndbg.commands.ArgparsedCommand(parser, aliases=["ropgadget"])
+@pwndbg.commands.ArgparsedCommand(
+    parser, aliases=["ropgadget"], category=CommandCategory.INTEGRATIONS
+)
 @pwndbg.commands.OnlyWithFile
-def rop(grep, argument):
+def rop(grep, argument) -> None:
     with tempfile.NamedTemporaryFile() as corefile:
 
         # If the process is running, dump a corefile so we get actual addresses.
-        if pwndbg.proc.alive:
+        if pwndbg.gdblib.proc.alive:
             filename = corefile.name
-            gdb.execute('gcore %s' % filename)
+            gdb.execute("gcore %s" % filename)
         else:
-            filename = pwndbg.proc.exe
+            filename = pwndbg.gdblib.proc.exe
 
         # Build up the command line to run
-        cmd = ['ROPgadget',
-               '--binary',
-               filename]
+        cmd = ["ROPgadget", "--binary", filename]
         cmd += argument
 
         try:
@@ -42,7 +43,7 @@ def rop(grep, argument):
 
         (stdout, stderr) = io.communicate()
 
-        stdout = stdout.decode('latin-1')
+        stdout = stdout.decode("latin-1")
 
         if not grep:
             print(stdout)
