@@ -1,18 +1,16 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """
 Wrapper for shell commands.
 """
 
 import os
 
-import gdb
+from pwnlib.util.misc import which
 
 import pwndbg.commands
-import pwndbg.which
+from pwndbg.commands import CommandCategory
 
-shellcmds = [
-    "asm", # pwntools
+pwncmd_names = ["asm", "constgrep", "disasm", "pwn", "unhex"]
+shellcmd_names = [
     "awk",
     "bash",
     "cat",
@@ -20,12 +18,9 @@ shellcmds = [
     "chmod",
     "chown",
     # "clear",
-    "constgrep", # pwntools
     "cp",
-    "cyclic", # pwntools
     "date",
     "diff",
-    "disasm", # pwntools
     "egrep",
     # "find", don't expose find as its an internal gdb command
     "grep",
@@ -48,7 +43,6 @@ shellcmds = [
     "ps",
     "pstree",
     "pwd",
-    "pwn", # pwntools
     "rm",
     "sed",
     "sh",
@@ -58,7 +52,6 @@ shellcmds = [
     "tail",
     "top",
     "touch",
-    "unhex", # pwntools
     "uniq",
     "vi",
     "vim",
@@ -69,18 +62,32 @@ shellcmds = [
     "zsh",
 ]
 
-shellcmds = filter(pwndbg.which.which, shellcmds)
+pwncmds = list(filter(which, pwncmd_names))
+shellcmds = list(filter(which, shellcmd_names))
 
-def register_shell_function(cmd):
-    def handler(*a):
+
+def register_shell_function(cmd, deprecated=False) -> None:
+    def handler(*a) -> None:
         if os.fork() == 0:
             os.execvp(cmd, (cmd,) + a)
         os.wait()
+        print(
+            "This command is deprecated in Pwndbg. Please use the GDB's built-in syntax for running shell commands instead: !%s <args>"
+            % cmd
+        )
+
+    doc = "Invokes `{}` shell command".format(cmd)
+    if deprecated:
+        doc += " (deprecated)"
 
     handler.__name__ = str(cmd)
-    handler.__doc__ = 'Invokes {}'.format(cmd)
+    handler.__doc__ = doc
 
-    pwndbg.commands.Command(handler, False)
+    pwndbg.commands.Command(handler, shell=True, category=CommandCategory.SHELL)
+
+
+for cmd in pwncmds:
+    register_shell_function(cmd)
 
 for cmd in shellcmds:
-    register_shell_function(cmd)
+    register_shell_function(cmd, deprecated=True)
